AlbumMethods

Struct AlbumMethods 

pub struct AlbumMethods<'a, C>
where C: 'a,
{ /* private fields */ }
A builder providing access to all methods supported on album resources. It is not used directly, but through the PhotosLibrary hub.

Example

Instantiate a resource builder

extern crate hyper;
extern crate hyper_rustls;
extern crate google_photoslibrary1 as photoslibrary1;

use photoslibrary1::{PhotosLibrary, FieldMask, hyper_rustls, hyper_util, yup_oauth2};

let secret: yup_oauth2::ApplicationSecret = Default::default();
let connector = hyper_rustls::HttpsConnectorBuilder::new()
    .with_native_roots()
    .unwrap()
    .https_only()
    .enable_http2()
    .build();

let executor = hyper_util::rt::TokioExecutor::new();
let auth = yup_oauth2::InstalledFlowAuthenticator::with_client(
    secret,
    yup_oauth2::InstalledFlowReturnMethod::HTTPRedirect,
    yup_oauth2::client::CustomHyperClientBuilder::from(
        hyper_util::client::legacy::Client::builder(executor).build(connector),
    ),
).build().await.unwrap();

let client = hyper_util::client::legacy::Client::builder(
    hyper_util::rt::TokioExecutor::new()
)
.build(
    hyper_rustls::HttpsConnectorBuilder::new()
        .with_native_roots()
        .unwrap()
        .https_or_http()
        .enable_http2()
        .build()
);
let mut hub = PhotosLibrary::new(client, auth);
// Usually you wouldn't bind this to a variable, but keep calling *CallBuilders*
// like `add_enrichment(...)`, `batch_add_media_items(...)`, `batch_remove_media_items(...)`, `create(...)`, `get(...)`, `list(...)`, `patch(...)`, `share(...)` and `unshare(...)`
// to build up your call.
let rb = hub.albums();

Implementations

Source

impl<'a, C> AlbumMethods<'a, C>

pub fn add_enrichment( &self, request: AddEnrichmentToAlbumRequest, album_id: &str, ) -> AlbumAddEnrichmentCall<'a, C>

Create a builder to help you perform the following task:

Adds an enrichment at a specified position in an app created created album.

Arguments
  • request - No description provided.
  • albumId - Required. Identifier of the app created album where the enrichment is to be added.
pub fn batch_add_media_items( &self, request: BatchAddMediaItemsToAlbumRequest, album_id: &str, ) -> AlbumBatchAddMediaItemCall<'a, C>

Create a builder to help you perform the following task:

Adds one or more app created media items in a user’s Google Photos library to an app created album. The media items and albums must have been created by the developer via the API. Media items are added to the end of the album. If multiple media items are given, they are added in the order specified in this call. Each album can contain up to 20,000 media items. Partial success is not supported. The entire request will fail if an invalid media item or album is specified.

Arguments
  • request - No description provided.
  • albumId - Required. Identifier of the Album that the media items are added to.
pub fn batch_remove_media_items( &self, request: BatchRemoveMediaItemsFromAlbumRequest, album_id: &str, ) -> AlbumBatchRemoveMediaItemCall<'a, C>

Create a builder to help you perform the following task:

Removes one or more app created media items from a specified app created album. The media items and the album must have been created by the developer via the API. Partial success is not supported. The entire request will fail and no action will be performed on the album if an invalid media item or album is specified.

Arguments
  • request - No description provided.
  • albumId - Required. Identifier of the Album that the media items are to be removed from.
pub fn create(&self, request: CreateAlbumRequest) -> AlbumCreateCall<'a, C>

Create a builder to help you perform the following task:

Creates an album in a user’s Google Photos library.

Arguments
  • request - No description provided.
pub fn get(&self, album_id: &str) -> AlbumGetCall<'a, C>

Create a builder to help you perform the following task:

Returns the app created album based on the specified albumId. The albumId must be the ID of an album created by your app.

Arguments
  • albumId - Required. Identifier of the album to be requested.
pub fn list(&self) -> AlbumListCall<'a, C>

Create a builder to help you perform the following task:

Lists all albums created by your app.

pub fn patch(&self, request: Album, id: &str) -> AlbumPatchCall<'a, C>

Create a builder to help you perform the following task:

Update the app created album with the specified id. Only the id, title and cover_photo_media_item_id fields of the album are read. The album must have been created by the developer via the API.

Arguments
  • request - No description provided.
  • id - Identifier for the album. This is a persistent identifier that can be used between sessions to identify this album.
pub fn share( &self, request: ShareAlbumRequest, album_id: &str, ) -> AlbumShareCall<'a, C>

Create a builder to help you perform the following task:

Marks an album as shared and accessible to other users. This action can only be performed on albums which were created by the developer via the API.

Arguments
  • request - No description provided.
  • albumId - Required. Identifier of the album to be shared. This albumId must belong to an album created by the developer.
pub fn unshare( &self, request: UnshareAlbumRequest, album_id: &str, ) -> AlbumUnshareCall<'a, C>

Create a builder to help you perform the following task:

Marks a previously shared album as private. This means that the album is no longer shared and all the non-owners will lose access to the album. All non-owner content will be removed from the album. If a non-owner has previously added the album to their library, they will retain all photos in their library. This action can only be performed on albums which were created by the developer via the API.

Arguments
  • request - No description provided.
  • albumId - Required. Identifier of the album to be unshared. This album id must belong to an album created by the developer.